<?php
include_once ("data/Api.php");
include_once ("data/Helper.php");
include_once ("data/Localization.php");

//Variablen initialisieren
//String/Int != 0 -> Check empty
if(empty($Club_ID)){
	throw new Exception("No club given");
}
//String -> Check empty
if(empty($Club_ContactMode)){
	$Club_ContactMode = "both";
}
else if($Club_ContactMode != "both" && $Club_ContactMode != "org" && $Club_ContactMode != "fallback"){
	throw new Exception("ContactMode has only 3 valid values: 'both' (default), 'org' and 'fallback', but '" . $Club_ContactMode . "' was set");
}
//String -> Check empty
if(empty($Club_Data)){
	$Club_Data = null;
}

//Initalisieren der Show-Data Variablen
$Club_Data_Array = Helper::ConvertParameterListToArray($Club_Data);

$Club_Show_Name = in_array("name", $Club_Data_Array);
$Club_Show_Logo = in_array("logo", $Club_Data_Array);
$Club_Show_ContactInfo = in_array("contactinfo", $Club_Data_Array);
$Club_Show_Address = in_array("address", $Club_Data_Array);
$Club_Show_Phone = in_array("phone", $Club_Data_Array);
$Club_Show_Mobile = in_array("mobile", $Club_Data_Array);
$Club_Show_Fax = in_array("fax", $Club_Data_Array);
$Club_Show_EMail = in_array("email", $Club_Data_Array);
$Club_Show_HomePage = in_array("homepage", $Club_Data_Array);
$Club_Show_Successes = in_array("successes", $Club_Data_Array);

$Club_Max_HeaderLevel = $Club_Show_Name && $Club_Show_Successes ? 5 : 6;

//Int != 0 -> Check empty
if(empty($Club_HeaderLevel)){
	$Club_HeaderLevel = 2;
}
else if(!is_numeric($Club_HeaderLevel) || $Club_HeaderLevel < 1 || $Club_HeaderLevel > $Club_Max_HeaderLevel){
	throw new Exception("HeaderLevel must be a numeric value between 1 and " . $Club_Max_HeaderLevel);
}

// Verein erhalten
$Club = Api::GetClub($Club_ID);

// Title der Seite manuell setzen - Hat keinen Effekt auf Title im <head> oder die Seitenberschrift!
// Dient lediglich evtl. Plug-Ins, die den Title auslesen (WordPress)
$GLOBALS["bsm_title"] = $Club->GetShortName();

// Kontaktname
$Club_ContactLine = $Club_Show_ContactInfo ? Helper::GetContactLine($Club) : null;
// Adresse
$Club_Address = $Club_Show_Address ? Helper::GetFullAddress($Club) : null;
// Telefon
$Club_Phone = $Club_Show_Phone ? Helper::GetContactInfoByMode($Club->GetPhone(), $Club->GetPhoneAlternative(), $Club_ContactMode, Localization::CLUB_SEPARATOR_PHONE) : null;
// Mobil
$Club_Mobile = $Club_Show_Mobile ? Helper::GetContactInfoByMode($Club->GetMobile(), $Club->GetMobileAlternative(), $Club_ContactMode, Localization::CLUB_SEPARATOR_MOBILE) : null;
// Fax
$Club_Fax = $Club_Show_Fax ? Helper::GetContactInfoByMode($Club->GetFax(), $Club->GetFaxAlternative(), $Club_ContactMode, Localization::CLUB_SEPARATOR_FAX) : null;
// EMail
$Club_EMail = null;
$Club_EMail_RenderBoth = false;

if($Club_Show_EMail){
	$Club_EMail = $Club->GetEMail();
	// Ist die EMail leer, wird die andere nur verwendet wenn:
	
	// a) beide angezeigt werden drfen
	// b) fallback (alt) verwendet werden darf
	
	// In jedem Fall wird im Folgenden nur 1 EMail angezeigt
	if(empty($Club_EMail) && ($Club_ContactMode == "both" || $Club_ContactMode == "fallback")){
		
		$Club_EMail = $Club->GetEMailAlternative();
	}
	// Ist die ausgesuchte EMail aber nicht leer, und die Alternative auch nicht, werden beide angezeigt,
	// falls dies eingestellt wurde
	else if($Club_ContactMode == "both" && !empty($Club->GetEMailAlternative())){
		$Club_EMail_RenderBoth = true;
	}
}

$Club_HomePage = $Club_Show_HomePage ? $Club->GetHomePage() : null;

$Club_HasInfos = !empty($Club_ContactLine) || !empty($Club_Address) || !empty($Club_Phone) || !empty($Club_Mobile) || !empty($Club_Fax) || !empty($Club_EMail) || !empty($Club_Show_HomePage);
// Erfolge
$Club_Successes = $Club_Show_Successes ? nl2br($Club->GetSuccesses()) : null;
?>
<div data-bsm="data-bsm" data-type="detail" data-object-type="club">
	<<?php echo ($Club_Show_Name ? "article" : "div") ?>>
		<?php if($Club_Show_Name):?>
		<h<?php echo $Club_HeaderLevel; ?>><?php echo $Club->GetShortName(); ?></h<?php echo $Club_HeaderLevel; ?>>
		<?php endif;?>   
	    <?php if($Club_Show_Logo && !empty($Club->GetLogo())): ?>
	    <img class="alignright" src="<?php echo $Club->GetLogo(); ?>" alt="" data-logo-for="<?php echo $Club->GetAcronym(); ?>" />
	    <?php endif; ?>
	    <?php if($Club_HasInfos): ?>
	    <p>
		    <?php if(!empty($Club_ContactLine)): ?>
		    <?php echo $Club_ContactLine; ?>
		    <br />
		    <?php endif; ?>
		    <?php if(!empty($Club_Address)): ?>
		    <?php echo $Club_Address; ?>
		    <br />
		    <?php endif; ?>
		    <?php if(!empty($Club_Phone)): ?>
		    <?php echo Localization::CLUB_LABEL_PHONE . " "; ?><a href="<?php echo Helper::ToTelLink($Club_Phone); ?>"><?php echo Helper::ToHtmlNumbers($Club_Phone); ?></a>
		    <br />
		    <?php endif; ?>
		    <?php if(!empty($Club_Mobile)): ?>
		    <?php echo Localization::CLUB_LABEL_MOBILE . " "; ?><a href="<?php echo Helper::ToTelLink($Club_Mobile); ?>"><?php echo Helper::ToHtmlNumbers($Club_Mobile); ?></a>
		    <br />
		    <?php endif; ?>
		    <?php if(!empty($Club_Fax)): ?>
		    <?php echo Localization::CLUB_LABEL_FAX . " "; ?><a href="<?php echo Helper::ToTelLink($Club_Fax); ?>"><?php echo Helper::ToHtmlNumbers($Club_Fax); ?></a>
		    <br />
		    <?php endif; ?>
		    <?php if(!empty($Club_EMail)): ?>
			<a href="<?php echo Helper::ToMailToLink($Club_EMail); ?>"><?php echo Helper::ToHtmlNumbers($Club_EMail); ?></a><?php if($Club_EMail_RenderBoth): ?>&nbsp;<?php echo Localization::CLUB_SEPARATOR_EMAIL; ?>&nbsp;<a href="<?php echo Helper::ToMailToLink($Club->GetEMailAlternative()); ?>"><?php echo Helper::ToHtmlNumbers($Club->GetEMailAlternative()); ?></a><?php endif; ?>
			<br />
			<?php endif; ?>
			<?php if(!empty($Club_HomePage)): ?>
			<a href="<?php echo $Club_HomePage; ?>" target="_blank"><?php echo Localization::CLUB_LABEL_HOMEPAGE; ?></a>
			<br />
			<?php endif; ?>
		</p>
		<?php endif; ?>
		<?php if(!empty($Club_Successes)): ?>
	    <section data-type="successes">
		    <h<?php echo $Club_HeaderLevel + ($Club_Show_Name ? 1 : 0); ?>><?php echo Localization::CLUB_HEADLINE_SUCCESSES; ?></h<?php echo $Club_HeaderLevel + ($Club_Show_Name ? 1 : 0); ?>>
		    <p>
		    	<?php echo $Club_Successes; ?>
		    </p>	    
	    </section>
	    <?php endif; ?>		
	</<?php echo ($Club_Show_Name ? "article" : "div") ?>>
</div>