<?php
include_once ("data/Api.php");
include_once ("data/Helper.php");
include_once ("data/Localization.php");

//Variablen initialisieren
//String -> Check empty
if(empty($ClubList_DetailsUrl)){
	$ClubList_DetailsUrl = null;
}
//Bool -> Check !isset
if(!isset($ClubList_Show_Search)){
	$ClubList_Show_Search = false;
}
//Int != 0 -> Check empty
if(empty($ClubList_District)){
	$ClubList_District = null;
}
else if(!is_numeric($ClubList_District)){
	throw new Exception("District must be a numeric value");
}
//Int != 0 -> Check empty
if(empty($ClubList_HeaderLevel)){
	$ClubList_HeaderLevel = 2;
}
else if(!is_numeric($ClubList_HeaderLevel) || $ClubList_HeaderLevel < 1 || $ClubList_HeaderLevel > 6){
	throw new Exception("HeaderLevel must be a numeric value between 1 and 6");
}
//String -> Check empty
if(empty($ClubList_ContactMode)){
	$ClubList_ContactMode = "both";
}
else if($ClubList_ContactMode != "both" && $ClubList_ContactMode != "org" && $ClubList_ContactMode != "fallback"){
	throw new Exception("ContactMode has only 3 valid values: 'both' (default), 'org' and 'fallback', but '" . $ClubList_ContactMode . "' was set");
}
//String -> Check empty
if(empty($ClubList_Organizations)){
	$ClubList_Organizations = null;
}
//String -> Check empty
if(empty($ClubList_Data)){
	$ClubList_Data = null;
}

//Initalisieren der Show-Data Variablen
$ClubList_Data_Array = Helper::ConvertParameterListToArray($ClubList_Data);

$ClubList_Show_Logo = in_array("logo", $ClubList_Data_Array);
$ClubList_Show_ContactInfo = in_array("contactinfo", $ClubList_Data_Array);
$ClubList_Show_Address = in_array("address", $ClubList_Data_Array);
$ClubList_Show_Phone = in_array("phone", $ClubList_Data_Array);
$ClubList_Show_Mobile = in_array("mobile", $ClubList_Data_Array);
$ClubList_Show_Fax = in_array("fax", $ClubList_Data_Array);
$ClubList_Show_EMail = in_array("email", $ClubList_Data_Array);
$ClubList_Show_HomePage = in_array("homepage", $ClubList_Data_Array);

$ClubList_Filter = $_GET["bsm_club_filter"];
//WordPress-Support
$ClubList_PageID = $_GET["page_id"];

$ClubList_ProvideDetails = !empty($ClubList_DetailsUrl);
?>
<div data-bsm="data-bsm" data-type="list" data-object-type="club">
	<?php if($ClubList_Show_Search): ?>
	<form method="GET">
		<fieldset>
				<legend><?php echo Localization::CLUBLIST_SEARCH_LEGEND; ?></legend>				
				<div data-searchentry-for="bsm_club_filter">
					<label for="bsm_club_filter"><?php echo Localization::CLUBLIST_SEARCH_LABEL; ?></label>
					<input type="search" id="bsm_club_filter" name="bsm_club_filter" placeholder="<?php echo Localization::CLUBLIST_SEARCH_PLACEHOLDER; ?>" value="<?php echo Helper::EncodeUserInputString($ClubList_Filter); ?>" />
				</div>
				<div data-searchentry-for="hidden_and_submit">
					<?php if (!empty($ClubList_PageID)): ?>
					<input type="hidden" name="page_id" value="<?php echo Helper::EncodeUserInputString($ClubList_PageID); ?>" />
					<?php endif; ?>				
					<button type="submit"><?php echo Localization::CLUBLIST_SEARCH_BUTTON; ?></button>
				</div>
		</fieldset>
	</form>
	<?php endif; ?>
	<?php 
		$ClubList_Organizations_Array = Helper::ConvertParameterListToArray($ClubList_Organizations);
		//Wenn Verbnde angegeben wurden, diese bercksichtigen und alle Vereine laden
		$ClubList_Clubs = empty($ClubList_Organizations_Array) ? Api::GetClubsForOrganization() : Api::GetClubs();
		
		$ClubList_Filtered = array();
		
		//Verbnde prfen, wenn kein leeres Array und nicht "all"
		$ClubList_Check_Organizations = !empty($ClubList_Organizations_Array) && !in_array("all", $ClubList_Organizations_Array);
		foreach($ClubList_Clubs as $club) {

			//Filtern nach Verband
			if($ClubList_Check_Organizations && !in_array($club->GetOrganizationID(), $ClubList_Organizations_Array)){
				
				continue;
			}
			
			//Filtern nach Filter
			if(!empty($ClubList_Filter) && stripos($club->GetShortName(), $ClubList_Filter) === false) {
			
				continue;
			}
			
			//Filtern nach Bezirk - nur wenn Nummer am Anfang der Vereinsnummer ist
			if(!empty($ClubList_District) && stripos($club->GetNumber(), $ClubList_District) !== 0){
				
				continue;
			}			
			
			array_push($ClubList_Filtered, $club);
		}

		if(empty($ClubList_Filtered)){
			
			echo Localization::CLUBLIST_SEARCH_NOENTRIES;
		}
	?>	
	<?php foreach($ClubList_Filtered as $club): ?>
	<?php	
	
		// Kontaktname
		$ClubList_ContactLine = $ClubList_Show_ContactInfo ? Helper::GetContactLine($club) : null;		
		// Adresse
		$ClubList_Address = $ClubList_Show_Address ? Helper::GetFullAddress($club) : null;
		// Telefon
		$ClubList_Phone = $ClubList_Show_Phone ? Helper::GetContactInfoByMode($club->GetPhone(), $club->GetPhoneAlternative(), $ClubList_ContactMode, Localization::CLUBLIST_SEPARATOR_PHONE) : null;
		// Mobil
		$ClubList_Mobile = $ClubList_Show_Mobile ? Helper::GetContactInfoByMode($club->GetMobile(), $club->GetMobileAlternative(), $ClubList_ContactMode, Localization::CLUBLIST_SEPARATOR_MOBILE) : null;
		// Fax
		$ClubList_Fax = $ClubList_Show_Fax ? Helper::GetContactInfoByMode($club->GetFax(), $club->GetFaxAlternative(), $ClubList_ContactMode, Localization::CLUBLIST_SEPARATOR_FAX) : null;
		// EMail
		$ClubList_EMail = null;
		$ClubList_EMail_RenderBoth = false;
		if($ClubList_Show_EMail){
			$ClubList_EMail = $club->GetEMail();
			// Ist die EMail leer, wird die andere nur verwendet wenn:
			
			// a) beide angezeigt werden drfen
			// b) fallback (alt) verwendet werden darf
			
			// In jedem Fall wird im Folgenden nur 1 EMail angezeigt
			if(empty($ClubList_EMail) && ($ClubList_ContactMode == "both" || $ClubList_ContactMode == "fallback")){
				
				$ClubList_EMail = $club->GetEMailAlternative();
			}
			// Ist die ausgesuchte EMail aber nicht leer, und die Alternative auch nicht, werden beide angezeigt,
			// falls dies eingestellt wurde
			else if($ClubList_ContactMode == "both" && !empty($club->GetEMailAlternative())){
				$ClubList_EMail_RenderBoth = true;
			}
		}
		
		$ClubList_HomePage = $ClubList_Show_HomePage ? $club->GetHomePage() : null;
		
		$ClubList_HasInfos = !empty($ClubList_ContactLine) || !empty($ClubList_Address) || !empty($ClubList_Phone) || !empty($ClubList_Mobile) || !empty($ClubList_Fax) || !empty($ClubList_EMail) || !empty($ClubList_HomePage);
	?>
	<article>		
	    <h<?php echo $ClubList_HeaderLevel; ?>>
			<?php if($ClubList_ProvideDetails): ?>
			<?php 
				$url = $ClubList_DetailsUrl;
				$query = parse_url($url, PHP_URL_QUERY);
	
				if($query){
					
					$url .= "&amp;bsm_club=";
				}else{
					
					$url .= "?bsm_club=";
				}
				
				$url .= $club->GetAcronym();
			?>
			<a href="<?php echo $url; ?>">
	        <?php endif; ?>    
	        <?php echo $club->GetShortName(); ?>
	        <?php if($ClubList_ProvideDetails): ?>
	        </a>
	        <?php endif; ?>   	
	    </h<?php echo $ClubList_HeaderLevel; ?>>	
	    <?php if($ClubList_Show_Logo && !empty($club->GetLogo())): ?>
	    <img class="alignright" src="<?php echo $club->GetLogo(); ?>" alt="" data-logo-for="<?php echo $club->GetAcronym(); ?>" />
	    <?php endif; ?>		
	    <?php if($ClubList_HasInfos): ?>
	    <p>	    	    
		    <?php if(!empty($ClubList_ContactLine)): ?>
		    <?php echo $ClubList_ContactLine; ?>
		    <br />
		    <?php endif; ?>
		    <?php if(!empty($ClubList_Address)): ?>
		    <?php echo $ClubList_Address; ?>
		    <br />
		    <?php endif; ?>
		    <?php if(!empty($ClubList_Phone)): ?>
		    <?php echo Localization::CLUBLIST_LABEL_PHONE . " "; ?><a href="<?php echo Helper::ToTelLink($ClubList_Phone); ?>"><?php echo Helper::ToHtmlNumbers($ClubList_Phone); ?></a>
		    <br />
		    <?php endif; ?>
		    <?php if(!empty($ClubList_Mobile)): ?>
		    <?php echo Localization::CLUBLIST_LABEL_MOBILE . " "; ?><a href="<?php echo Helper::ToTelLink($ClubList_Mobile); ?>"><?php echo Helper::ToHtmlNumbers($ClubList_Mobile); ?></a>
		    <br />
		    <?php endif; ?>
		    <?php if(!empty($ClubList_Fax)): ?>
		    <?php echo Localization::CLUBLIST_LABEL_FAX . " "; ?><a href="<?php echo Helper::ToTelLink($ClubList_Fax); ?>"><?php echo Helper::ToHtmlNumbers($ClubList_Fax); ?></a>
		    <br />
		    <?php endif; ?>
		    <?php if(!empty($ClubList_EMail)): ?>
			<a href="<?php echo Helper::ToMailToLink($ClubList_EMail); ?>"><?php echo Helper::ToHtmlNumbers($ClubList_EMail); ?></a><?php if($ClubList_EMail_RenderBoth): ?>&nbsp;<?php echo Localization::CLUBLIST_SEPARATOR_EMAIL; ?>&nbsp;<a href="<?php echo Helper::ToMailToLink($club->GetEMailAlternative()); ?>"><?php echo Helper::ToHtmlNumbers($club->GetEMailAlternative()); ?></a><?php endif; ?>
			<br />
			<?php endif; ?>
			<?php if(!empty($ClubList_HomePage)): ?>
			<a href="<?php echo $ClubList_HomePage; ?>" target="_blank"><?php echo Localization::CLUBLIST_LABEL_HOMEPAGE; ?></a>
			<br />
			<?php endif; ?>
		</p>
		<?php endif; ?>
	</article>
	<?php endforeach; ?>
</div>