<?php
include_once ("data/Api.php");
include_once ("data/Helper.php");
include_once ("data/Localization.php");

//Variablen initialisieren
//Int != 0 -> Check empty
if(empty($Organization_HeaderLevel)){
	$Organization_HeaderLevel = 2;
}
else if(!is_numeric($Organization_HeaderLevel) || $Organization_HeaderLevel < 1 || $Organization_HeaderLevel > 6){
	throw new Exception("HeaderLevel must be a numeric value between 1 and 6");
}
//String -> Check empty
if(empty($Organization_ContactMode)){
	$Organization_ContactMode = "both";
}
else if($Organization_ContactMode != "both" && $Organization_ContactMode != "org" && $Organization_ContactMode != "fallback"){
	throw new Exception("ContactMode has only 3 valid values: 'both' (default), 'org' and 'fallback', but '" . $Organization_ContactMode . "' was set");
}
//String -> Check empty
if(empty($Organization_Data)){
	$Organization_Data = null;
}

//Initalisieren der Show-Data Variablen
$Organization_Data_Array = Helper::ConvertParameterListToArray($Organization_Data);

$Organization_Show_Name = in_array("name", $Organization_Data_Array);
$Organization_Show_Logo = in_array("logo", $Organization_Data_Array);
$Organization_Show_ContactInfo = in_array("contactinfo", $Organization_Data_Array);
$Organization_Show_Address = in_array("address", $Organization_Data_Array);
$Organization_Show_Phone = in_array("phone", $Organization_Data_Array);
$Organization_Show_Mobile = in_array("mobile", $Organization_Data_Array);
$Organization_Show_Fax = in_array("fax", $Organization_Data_Array);
$Organization_Show_EMail = in_array("email", $Organization_Data_Array);
$Organization_Show_HomePage = in_array("homepage", $Organization_Data_Array);

$Organization = Api::GetOrganization();
// Kontaktname
$Organization_ContactLine = $Organization_Show_ContactInfo ? Helper::GetContactLine($Organization) : null;
// Adresse
$Organization_Address = $Organization_Show_Address ? Helper::GetFullAddress($Organization) : null;
// Telefon
$Organization_Phone = $Organization_Show_Phone ? Helper::GetContactInfoByMode($Organization->GetPhone(), $Organization->GetPhoneAlternative(), $Organization_ContactMode, Localization::ORGANIZATION_SEPARATOR_PHONE): null;
// Mobil
$Organization_Mobile = $Organization_Show_Mobile ? Helper::GetContactInfoByMode($Organization->GetMobile(), $Organization->GetMobileAlternative(), $Organization_ContactMode, Localization::ORGANIZATION_SEPARATOR_MOBILE) : null;
// Fax
$Organization_Fax = $Organization_Show_Fax ? Helper::GetContactInfoByMode($Organization->GetFax(), $Organization->GetFaxAlternative(), $Organization_ContactMode, Localization::ORGANIZATION_SEPARATOR_FAX) : null;
// EMail
$Organization_EMail = null;
$Organization_EMail_RenderBoth = false;
if($Organization_Show_EMail){
	$Organization_EMail = $Organization->GetEMail();
	// Ist die EMail leer, wird die andere nur verwendet wenn:
	
	// a) beide angezeigt werden drfen
	// b) fallback (alt) verwendet werden darf
	
	// In jedem Fall wird im Folgenden nur 1 EMail angezeigt
	if(empty($Organization_EMail) && ($Organization_ContactMode == "both" || $Organization_ContactMode == "fallback")){
		
		$Organization_EMail = $Organization->GetEMailAlternative();
	}
	// Ist die ausgesuchte EMail aber nicht leer, und die Alternative auch nicht, werden beide angezeigt,
	// falls dies eingestellt wurde
	else if($Organization_ContactMode == "both" && !empty($Organization->GetEMailAlternative())){
		$Organization_EMail_RenderBoth = true;
	}
}

$Organization_HomePage = $Organization_Show_HomePage ? $Organization->GetHomePage() : null;

$Organization_HasInfos = !empty($Organization_ContactLine) || !empty($Organization_Address) || !empty($Organization_Phone) || !empty($Organization_Mobile) || !empty($Organization_Fax) || !empty($Organization_EMail) || !empty($Organization_HomePage);
?>
<div data-bsm="data-bsm" data-type="detail" data-object-type="organization">
	<<?php echo ($Organization_Show_Name ? "article" : "div") ?>>
		<?php if($Organization_Show_Name): ?>
		<h<?php echo $Organization_HeaderLevel; ?>><?php echo $Organization->GetName(); ?></h<?php echo $Organization_HeaderLevel; ?>>
		<?php endif; ?>		  
	    <?php if($Organization_Show_Logo && !empty($Organization->GetLogo())): ?>
	    <img class="alignright" src="<?php echo $Organization->GetLogo(); ?>" alt="" data-logo-for="<?php echo $Organization->GetAcronym(); ?>" />
	    <?php endif; ?>
	    <?php if($Organization_HasInfos): ?>
	    <p>
		    <?php if(!empty($Organization_ContactLine)): ?>
		    <?php echo $Organization_ContactLine; ?>
		    <br />
		    <?php endif; ?>
		    <?php if(!empty($Organization_Address)): ?>
		    <?php echo $Organization_Address; ?>
		    <br />
		    <?php endif; ?>
		    <?php if(!empty($Organization_Phone)): ?>
		    <?php echo Localization::ORGANIZATION_LABEL_PHONE . " "; ?><a href="<?php echo Helper::ToTelLink($Organization_Phone); ?>"><?php echo Helper::ToHtmlNumbers($Organization_Phone); ?></a>
		    <br />
		    <?php endif; ?>
		    <?php if(!empty($Organization_Mobile)): ?>
		    <?php echo Localization::ORGANIZATION_LABEL_MOBILE . " "; ?><a href="<?php echo Helper::ToTelLink($Organization_Mobile); ?>"><?php echo Helper::ToHtmlNumbers($Organization_Mobile); ?></a>
		    <br />
		    <?php endif; ?>
		    <?php if(!empty($Organization_Fax)): ?>
		    <?php echo Localization::ORGANIZATION_LABEL_FAX . " "; ?><a href="<?php echo Helper::ToTelLink($Organization_Fax); ?>"><?php echo Helper::ToHtmlNumbers($Organization_Fax); ?></a>
		    <br />
		    <?php endif; ?>
		    <?php if(!empty($Organization_EMail)): ?>
			<a href="<?php echo Helper::ToMailToLink($Organization_EMail); ?>"><?php echo Helper::ToHtmlNumbers($Organization_EMail); ?></a><?php if($Organization_EMail_RenderBoth): ?>&nbsp;<?php echo Localization::ORGANIZATION_SEPARATOR_EMAIL; ?>&nbsp;<a href="<?php echo Helper::ToMailToLink($Organization->GetEMailAlternative()); ?>"><?php echo Helper::ToHtmlNumbers($Organization->GetEMailAlternative()); ?></a><?php endif; ?>
			<br />
			<?php endif; ?>
			<?php if(!empty($Organization_HomePage)): ?>
			<a href="<?php echo $Organization_HomePage; ?>" target="_blank"><?php echo Localization::ORGANIZATION_LABEL_HOMEPAGE; ?></a>
			<br />
			<?php endif; ?>
		</p>
		<?php endif; ?>		
	</<?php echo ($Organization_Show_Name ? "article" : "div") ?>>
</div>