<?php
include_once ("data/Api.php");
include_once ("data/Helper.php");
include_once ("data/Localization.php");

// Variablen initialisieren
// String/Int != 0 -> Check empty
if (empty ( $StatisticLeagueGroup_ID )) {
	throw new Exception ( "No league given" );
}

if (empty ( $StatisticLeagueGroup_Category )) {
	$StatisticLeagueGroup_Category = "offense";
} else if ($StatisticLeagueGroup_Category != "offense" && $StatisticLeagueGroup_Category != "defense" && $StatisticLeagueGroup_Category != "pitching") {
	throw new Exception ( "Category has only 3 valid values: 'offense' (default), 'defense' and 'pitching', but '" . $StatisticLeagueGroup_Category . "' was set" );
}

// String -> Check empty
if(empty($StatisticLeagueGroup_TeamStatisticUrl)){	
	$StatisticLeagueGroup_TeamStatisticUrl = null;
}

//String -> Check empty
if(empty($StatisticLeagueGroup_CaptionMode)){
	$StatisticLeagueGroup_CaptionMode = 'none';
}
$StatisticLeagueGroup_CaptionMode = Helper::ConvertParameterListToArray($StatisticLeagueGroup_CaptionMode);
$CaptionModeValidEntries = [ 'none', 'season', 'league', 'category' ];
if(!Helper::hasArrayOnlyValidEntries($StatisticLeagueGroup_CaptionMode, $CaptionModeValidEntries)){
	throw new Exception("captionmode has these valid values: '" . Helper::ToDelimitedList($CaptionModeValidEntries) . "', but '" . Helper::ToDelimitedList($StatisticLeagueGroup_CaptionMode) . "' was set");
}

//String -> Check empty
if(empty($StatisticLeagueGroup_LogoMode)){
	$StatisticLeagueGroup_LogoMode = "none";
}
else if ($StatisticLeagueGroup_LogoMode != "none" && $StatisticLeagueGroup_LogoMode != "left" && $StatisticLeagueGroup_LogoMode != "right" && $StatisticLeagueGroup_LogoMode != "only") {
	throw new Exception ( "LogoMode has only these valid values: 'none' (default), 'left', 'right', 'only', but '" . $StatisticLeagueGroup_LogoMode . "' was set" );
}

//String/Int != 0 -> Check empty
if(empty($StatisticLeagueGroup_Highlight)){
	$StatisticLeagueGroup_Highlight = null;
}

// String -> Check empty
if (empty ( $StatisticLeagueGroup_Data )) {
	$StatisticLeagueGroup_Data = null;
}

// String -> Check empty
if(empty($StatisticLeagueGroup_DataTables)){
	$StatisticLeagueGroup_DataTables = null;
}

// Initalisieren der Show Variablen
$StatisticLeagueGroup_Data_Array = Helper::ConvertParameterListToArray ( $StatisticLeagueGroup_Data );

$StatisticLeagueGroup_Show_TeamName = in_array ( "team", $StatisticLeagueGroup_Data_Array );
$StatisticLeagueGroup_Show_TeamAcronym = in_array ( "teamacronym", $StatisticLeagueGroup_Data_Array );

//$StatisticLeagueGroup_Max_HeaderLevel = $League_Show_Name && ($League_Show_Manager || $League_Show_Statistician || $League_Show_UmpireSelector || $League_Show_GameMode || $League_Show_GameRoundModeDescription || $League_Show_OtherInformation) ? 5 : 6;

//Int != 0 -> Check empty
/*
if(empty($StatisticLeagueGroup_HeaderLevel)){
	$StatisticLeagueGroup_HeaderLevel = 2;
}
else if(!is_numeric($StatisticLeagueGroup_HeaderLevel) || $StatisticLeagueGroup_HeaderLevel < 1 || $StatisticLeagueGroup_HeaderLevel > $StatisticLeagueGroup_Max_HeaderLevel){
	throw new Exception("HeaderLevel must be a numeric value between 1 and " . $StatisticLeagueGroup_Max_HeaderLevel);
}
*/

$StatisticLeagueGroup_Show_TeamStatistic_Link = !empty($StatisticLeagueGroup_TeamStatisticUrl);
if($StatisticLeagueGroup_Show_TeamStatistic_Link) {
	$url = $StatisticLeagueGroup_TeamStatisticUrl;
	$query = parse_url($url, PHP_URL_QUERY);
	
	if($query){
		$url .= "&amp;";
	}else{
		$url .= "?";
	}
	
	if($StatisticLeagueGroup_Category){
		$url .= "bsm_category=" . $StatisticLeagueGroup_Category;
	}
	
	$StatisticLeagueGroup_TeamStatisticUrl = $url;
}

$StatisticLeagueGroup_Highlight_Array = Helper::ConvertParameterListToArray($StatisticLeagueGroup_Highlight);


// Statistic Liga erhalten
$StatisticLeague = null;

switch ($StatisticLeagueGroup_Category) {
	case "offense" :
		$StatisticLeague = Api::GetStatisticsLeague( $StatisticLeagueGroup_ID, "offense" );
		include 'StatisticLeagueGroupBatting_sub.php';
		break;
	
	case "defense" :
		$StatisticLeague = Api::GetStatisticsLeague( $StatisticLeagueGroup_ID, "defense" );
		include 'StatisticLeagueGroupFielding_sub.php';
		break;
	
	case "pitching" :
		$StatisticLeague = Api::GetStatisticsLeague( $StatisticLeagueGroup_ID, "pitching" );
		include 'StatisticLeagueGroupPitching_sub.php';
		break;
	
	default :
		;
		break;
}


// *** DataTables ***
$DataTablesOptions = "";
if (!empty($StatisticLeagueGroup_DataTables)) {
	// if only true is set => use default config
	if($StatisticLeagueGroup_DataTables === true) {
		$DataTablesOptions = 
		"
					{
						paging: false,
						order: [],
					}
		";
	}
	// if a bracket is found => use the string as options object
	if(!empty($StatisticLeagueGroup_DataTables) && str_contains($StatisticLeagueGroup_DataTables, "{")) {
		$DataTablesOptions = $StatisticLeagueGroup_DataTables;
	}
	
}

?>
<?php if (!empty($StatisticLeagueGroup_DataTables)): ?>
<script type="text/javascript">

	(function($){
		$(document).ready(function(){
			$('div[data-type="table"][data-object-type="statistics"] > table').DataTable(<?php echo $DataTablesOptions?>);
		});
	})(jQuery.noConflict());

</script>
<?php endif; ?>