<?php
// Include DTOs
include_once ("objects/Club.php");
include_once ("objects/ContactInfo.php");
include_once ("objects/Course.php");
include_once ("objects/Field.php");
include_once ("objects/Functionary.php");
include_once ("objects/League.php");
include_once ("objects/LeagueEntry.php");
include_once ("objects/LeagueGroup.php");
include_once ("objects/License.php");
include_once ("objects/Matchup.php");
include_once ("objects/MatchPenalty.php");
include_once ("objects/Organization.php");
include_once ("objects/Person.php");
include_once ("objects/Table.php");
include_once ("objects/Team.php");
include_once ("objects/StatisticLeagueGroup.php");
include_once ("objects/StatisticLeagueGroupTeam.php");
include_once ("objects/StatisticClub.php");
include_once ("objects/StatisticLeagueGroupLeaders.php");
include_once ("objects/StatisticPerson.php");
include_once ("objects/MatchBoxscore.php");

class SortConfiguration {

	private $Field;
	
	private $Direction;
	
	public function __construct($field, $direction) {
	
		$this->Field = $field;
		$this->Direction = empty($direction) ? "asc" : $direction;
	}
	
	public function GetField(){
	
		return $this->Field;
	}
	
	public function GetDirection(){
	
		return $this->Direction;
	}
}

class FilterConfiguration {

	private $Field;
	
	private $Value;
	
	public function __construct($field, $value){
		
		$this->Field = $field;
		$this->Value = $value;
	}
	
	public function GetField(){
	
		return $this->Field;
	}
	
	public function GetValue(){
	
		return $this->Value;
	}
}

class Api {
	
	/* REGION API */
	
	/* REGION CONSTANTS - DO NOT CHANGE */
	
 	const API_URL = "https://bsm.baseball-softball.de";
// 	const API_URL = "https://bsm-staging.maxigs.net";
	
	const TIMEOUT = 300;
	
	const TIME_ZONE = "Europe/Berlin";
	
	/* ENDREGION CONSTANTS */
	
	/* REGION CONFIG */
	
	// Hier den Api-Schlssel eintragen
	private static $ApiKey = "";
	
	// Hier Verbands-ID eintragen (ohne Hochkommata, bspw.: private static $OrgId = 4711)
	private static $OrgId = 0;
	
	// Hier Season eintragen (ohne Hochkommata, bspw.: private static $Season = 2016)
	private static $Season = 0;
	
	/* ENDREGION CONFIG */
	
	private static function ApiCall($resource, array $sortings = null, array $filter = null, $useCompactMode = false) {
		$url = self::API_URL . "/" . $resource . ".json?api_key=" . self::$ApiKey;
		
		if(!empty($sortings)){
			
			foreach ($sortings as $sort){
			
				$url = $url . "&sort[" . $sort->GetField() . "]=" . $sort->GetDirection();
			}		
		}
		
		if(!empty($filter)){
			
			foreach ($filter as $filterConfig){
				
				$url = $url . "&filter[" . $filterConfig->GetField() . "][]=" . $filterConfig->GetValue();
			}
		}
		
		//TODO - nur temporr!
		if($useCompactMode){
			$url = $url . "&compact=true";
		}
		
		$debug = bsm_get_option("debug");
		if($debug === true) {
			echo "ApiCall URL: <br/><em>" . $url . "</em><br/>"; // RR
			error_log("ApiCall URL: " . $url);
		}
		
		//PHP Timeout
		set_time_limit(self::TIMEOUT);

		$curl = curl_init();
		
		//SSL - Optionen
		curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, 0);
		curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, 0);
		
		curl_setopt($curl, CURLOPT_URL, $url);
		curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($curl, CURLOPT_FOLLOWLOCATION, true);
		
		//Timeout
		curl_setopt($curl, CURLOPT_CONNECTTIMEOUT , self::TIMEOUT);
		curl_setopt($curl, CURLOPT_TIMEOUT, self::TIMEOUT);
		
		if(str_contains(self::API_URL, "staging")) {
			curl_setopt($curl, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
			curl_setopt($curl, CURLOPT_USERPWD, "bsm:bananarama");
		}

		$result = curl_exec($curl);
		
		curl_close($curl);

		/*
		if($debug === true) {
			echo("Result: " . $result . "<br/>");
		}
		*/
		
		$json = json_decode($result);

		//Fehlerbehandlung
		//Kein Result
		if(!isset($json)){
			//throw new Exception("Api call failed - no valid data was returned from the server - please check your configuration, e.g. 'apiKey'");
			echo("Api call failed - no valid data was returned from the server - please check your configuration, e.g. 'apiKey'");
		}				
		//Fehlermeldung vom Server
		else if(!empty($json->status) && $json->status == "500" && !empty($json->error)){
			throw new Exception("Api call failed - there was a problem processing the request - error message returned by server: '" . $json->error . "'");
		}
		
		return $json;
	}

	public static function InitConfig($apiKey, $orgId, $season){		
		
		// Nur wenn Wert gegeben ist, den DEFAULT berschreiben
		if(!empty($apiKey)){
		
			self::$ApiKey = $apiKey;
		}
		// Nur wenn Wert gegeben ist, den DEFAULT berschreiben
		if(!empty($orgId) && is_numeric($orgId)){
		
			self::$OrgId = $orgId;
		}
		// Nur wenn Wert gegeben ist, den DEFAULT berschreiben
		if(!empty($season) && is_numeric($season)){
			
			self::$Season = $season;
		}
	}
	
	private static function isDbv() {
		// Vereinbarung: Wenn orgId <= 0 dann ist es der DBV. Dann muss ein anderer Pfad genommen werden.
		return self::$OrgId <= 0;
	}
	
	private static function GetOrgRoot() {
		if(self::isDbv()){

			return "federations/1";
		} else {

			return "organizations/" . self::$OrgId;
		}		
	}
	
	/* END REGION API */	
	
	public static function GetOrganization() {
			
		// Erhalte Organization im JSON-Format
// 		$json = self::ApiCall("organizations/" . self::$OrgId);
		$json = self::ApiCall(self::GetOrgRoot());
		
		return new Organization($json);
	}	
	
	public static function GetLeaguesForOrganization($season = null) {
		
		$filter = array();
		$seasonFilter = empty($season) ? self::$Season : $season; 
		if(!empty($seasonFilter)){
			array_push($filter, new FilterConfiguration("seasons", $seasonFilter));
		}
		// Erhalte OrganizationLeague im JSON-Format
		$json = self::ApiCall(self::GetOrgRoot() . "/leagues", null, $filter);
	
		$result = array ();
		foreach ($json as $jsonElement) {
				
			array_push($result, new League($jsonElement));
		}

		return $result;
	}	
	
	public static function GetFunctionariesForOrganization() {
		
		// Erhalte OrganizationFunction im JSON-Format
		// Spezialfall bei DBV
		$json = self::ApiCall( self::GetOrgRoot() . (self::isDbv() ? "/federation_functions" : "/organization_functions") );
		
		$result = array ();
		foreach ($json as $jsonElement) {
			
			array_push($result, new Functionary($jsonElement));
		}
		
		return $result;
	}
	
	public static function GetClubsForOrganization() {
		
		// Erhalte Club-Array im JSON-Format
		// Spezialfall bei DBV
		$json = self::ApiCall( (self::isDbv() ? "" : self::GetOrgRoot() . "/") . "clubs");
		
		$result = array ();
		foreach ($json as $jsonElement) {
			
			array_push($result, new Club($jsonElement));
		}
		
		return $result;
	}
	
	public static function GetClubs() {
	
		// Erhalte Club-Array im JSON-Format
		$json = self::ApiCall("clubs");
	
		$result = array ();
		foreach ($json as $jsonElement) {
				
			array_push($result, new Club($jsonElement));
		}
	
		return $result;
	}
	
	public static function GetLicenses(){
	
		$sortings = array(new SortConfiguration("last_name", "asc"));
		
		// Erhalte License-Array im JSON-Format
		$json = self::ApiCall("licenses", $sortings);
	
		$result = array ();
		foreach ($json as $jsonElement) {
	
			array_push($result, new License($jsonElement));
		}
	
		return $result;
	}
	
	public static function GetLicensesForOrganization(){
	
		$sortings = array(new SortConfiguration("last_name", "asc"));
		
		// Erhalte License-Array im JSON-Format
		$json = self::ApiCall(self::GetOrgRoot() . "/licenses", $sortings);
	
		$result = array ();
		foreach ($json as $jsonElement) {
	
			array_push($result, new License($jsonElement));
		}
	
		return $result;
	}
	
	public static function GetTeamsForOrganization(){
		
		// Erhalte Team-Array im JSON-Format
		$json = self::ApiCall(self::GetOrgRoot() . "/teams");
		
		$result = array();
		foreach ($json as $jsonElement) {
			
			array_push($result, new Team($jsonElement));
		}
		
		return $result;
	}

	public static function GetMatchPenaltiesForOrganization($season = null){
	
		$filter = array();
		$seasonFilter = empty($season) ? self::$Season : $season; 
		if(!empty($seasonFilter)){
			array_push($filter, new FilterConfiguration("seasons", $seasonFilter));
		}
		// Erhalte MatchPenalty-Array im JSON-Format
		$json = self::ApiCall(self::GetOrgRoot() . "/match_penalties", null, $filter);
	
		$result = array();
		foreach ($json as $jsonElement) {
				
			//Manueller Filter
			$matchPenalty = new MatchPenalty($jsonElement);
			if(self::isDbv()) {
				// sollte eigentlich immer false sein, weil jeder Eintrag die Federation 1 hat
				if($matchPenalty->GetClub()->GetFederationID() != 1){ 
					continue;
				}
			} else {
				if($matchPenalty->GetClub()->GetOrganizationID() != self::$OrgId){
					continue;
				}
			}
			array_push($result, $matchPenalty);
		}
	
		return $result;
	}
	
	public static function GetCoursesForOrganization($category, $status = null) {	

		$filter = array();
		$statusFilter = empty($status) ? "published" : $status;
		if(!empty($statusFilter)){
			array_push($filter, new FilterConfiguration("status", $statusFilter));
		}
		if(!empty($category)){			
			array_push($filter, new FilterConfiguration("category", $category));
		}		
		// Erhalte Course-Array im JSON-Format
		$json = self::ApiCall(self::GetOrgRoot() . "/courses", null, $filter);
		
		$result = array();
		foreach ($json as $jsonElement) {
				
			array_push($result, new Course($jsonElement));
		}
		
		return $result;
	}
	
	public static function GetCourse($id) {
	
		// Erhalte Course im JSON-Format
		$json = self::ApiCall("courses/" . $id);
	
		return new Course($json);
	}
	
	public static function GetLeagueGroupsForOrganization($season = null) {
	
		$filter = array();
		$seasonFilter = empty($season) ? self::$Season : $season; 
		if(!empty($seasonFilter)){
			array_push($filter, new FilterConfiguration("seasons", $seasonFilter));
		}
		// Erhalte LeagueGroup-Array im JSON-Format
		$json = self::ApiCall(self::GetOrgRoot() . "/league_groups", null, $filter);
	
		$result = array();
		foreach ($json as $jsonElement) {
			
			array_push($result, new LeagueGroup($jsonElement));
		}
		
		return $result;
	}
	
	public static function GetLeagueGroup($id) {
	//public static function GetLeagueGroup($leagueId, $leagueGroupId) {
		
		// Erhalte LeagueGroup im JSON-Format
		$json = self::ApiCall("leagues/" . $id);
		//$json = self::ApiCall("leagues/" . $leagueId . "/leagues/" . $leagueGroupId);
		
		return new LeagueGroup($json);
	}
	
	public static function GetLeague($id) {
	
		// Erhalte League im JSON-Format
		$json = self::ApiCall("leagues/" . $id);
	
		return new League($json);
	}	
	
	public static function GetTable($id, $season = null) {
	
		$filter = array();
		$seasonFilter = empty($season) ? self::$Season : $season;
		
		if(!empty($seasonFilter)){
			array_push($filter, new FilterConfiguration("season", $seasonFilter));
		}
		// Erhalte Table im JSON-Format
		// RR: hier will der API Call eigentlich filters... statt filter. Falls nicht im API lsbar, mach ich hier eine nderung.
		$json = self::ApiCall("leagues/" . $id . "/table", null, $filter);
	
		return new Table($json);
	}
	
	public static function GetLeagueEntriesForLeague($id) {
	
		// Erhalte LeagueEntry-Array im JSON-Format
		$json = self::ApiCall("leagues/" . $id . "/league_entries");
	
		$result = array();
		foreach ($json as $jsonElement) {
			
			array_push($result, new LeagueEntry($jsonElement));
		}
		
		return $result;
	}
	
	public static function GetMatchesForLeague($id, $gamedays = null, $season = null, $sortByLeague = false, $useCompactMode = false) {
		
		$filter = array();
		$seasonFilter = empty($season) ? self::$Season : $season; 
		if(!empty($seasonFilter)){
			array_push($filter, new FilterConfiguration("season", $seasonFilter));
		}
		if(!empty($gamedays)){
			array_push($filter, new FilterConfiguration("gamedays", $gamedays));
		}
		//$sortings = $sortByLeague ? array(new SortConfiguration("league_sort", "asc"), new SortConfiguration("time", "asc")) : null;
		// RF: 2019-04-25: Sortierung gendert damit DH zusammenbleiben
		$sortings = $sortByLeague ? array(new SortConfiguration("league_sort", "asc"), new SortConfiguration("date", "asc"), new SortConfiguration("match_id", "asc")) : null;
		// Erhalte Match-Array im JSON-Format - TODO: $useCompactMode nur temporr!
		$json = self::ApiCall("leagues/" . $id . "/matches", $sortings, $filter, $useCompactMode);
		
		$result = array();
		foreach ($json as $jsonElement) {
			
			array_push($result, new Matchup($jsonElement));
		}
		
		return $result;
	}
	
	public static function GetMatchesForClub($id, $gamedays = null, $season = null, $sortByLeague = false, $useCompactMode = false) {
	
		$filter = array();
		$seasonFilter = empty($season) ? self::$Season : $season;
		if(!empty($seasonFilter)){
			array_push($filter, new FilterConfiguration("seasons", $seasonFilter));
		}
		if(!empty($gamedays)){
			array_push($filter, new FilterConfiguration("gamedays", $gamedays));
		}
		//$sortings = $sortByLeague ? array(new SortConfiguration("league_sort", "asc"), new SortConfiguration("time", "asc")) : null;
		// RF: 2019-04-25: Sortierung gendert damit DH zusammenbleiben
		$sortings = $sortByLeague ? array(new SortConfiguration("league_sort", "asc"), new SortConfiguration("date", "asc"), new SortConfiguration("match_id", "asc")) : null;
		// Erhalte Match-Array im JSON-Format - TODO: $useCompactMode nur temporr!
		$json = self::ApiCall("clubs/" . $id . "/matches", $sortings, $filter, $useCompactMode);
	
		$result = array();
		foreach ($json as $jsonElement) {
			array_push($result, new Matchup($jsonElement));
		}
				
		return $result;
	}
	
	public static function GetMatchesForOrganization($gamedays = null, $season = null, $sortByLeague = false, $useCompactMode = false) {
	
		$filter = array();
		$seasonFilter = empty($season) ? self::$Season : $season;
		if(!empty($seasonFilter)){
			array_push($filter, new FilterConfiguration("seasons", $seasonFilter));
		}
		if(!empty($gamedays)){
			array_push($filter, new FilterConfiguration("gamedays", $gamedays));
		}
		//$sortings = $sortByLeague ? array(new SortConfiguration("league_sort", "asc"), new SortConfiguration("time", "asc")) : null;
		// RF: 2019-04-25: Sortierung gendert damit DH zusammenbleiben
		$sortings = $sortByLeague ? array(new SortConfiguration("league_sort", "asc"), new SortConfiguration("date", "asc"), new SortConfiguration("match_id", "asc")) : null;
		// Erhalte Match-Array im JSON-Format - TODO: $useCompactMode nur temporr!
		$json = self::ApiCall(self::GetOrgRoot() . "/matches", $sortings, $filter, $useCompactMode);
	
		$result = array();
		foreach ($json as $jsonElement) {
			array_push($result, new Matchup($jsonElement));
		}
	
		return $result;
	}
	
	public static function GetMatches($gamedays = null, $season = null, $sortByLeague = false, $useCompactMode = false) {
	
		$filter = array();
		$seasonFilter = empty($season) ? self::$Season : $season; 
		if(!empty($seasonFilter)){
			array_push($filter, new FilterConfiguration("seasons", $seasonFilter));
		}
		if(!empty($gamedays)){
			array_push($filter, new FilterConfiguration("gamedays", $gamedays));
		}
		//$sortings = $sortByLeague ? array(new SortConfiguration("league_sort", "asc"), new SortConfiguration("time", "asc")) : null;
		// RF: 2019-04-25: Sortierung gendert damit DH zusammenbleiben
		$sortings = $sortByLeague ? array(new SortConfiguration("league_sort", "asc"), new SortConfiguration("date", "asc"), new SortConfiguration("match_id", "asc")) : null;
		// Erhalte Match-Array im JSON-Format - TODO: $useCompactMode nur temporr!
		$json = self::ApiCall("matches", $sortings, $filter, $useCompactMode);

		$result = array();
		foreach ($json as $jsonElement) {
			array_push($result, new Matchup($jsonElement));
		}
		
		return $result;
	}
	
	public static function GetMatch($id) {
	
		// Erhalte Match im JSON-Format
		$json = self::ApiCall("matches/" . $id);
	
		return new Matchup($json);
	}
	
	public static function GetClub($id) {
		
		// Erhalte Club im JSON-Format
		$json = self::ApiCall("clubs/" . $id);
		
		return new Club($json);
	}	
	
	public static function GetFunctionariesForClub($id) {
	
		// Erhalte Function im JSON-Format
		$json = self::ApiCall("clubs/" . $id . "/club_functions");
	
		$result = array ();
		foreach ($json as $jsonElement) {
				
			array_push($result, new Functionary($jsonElement));
		}
	
		return $result;
	}
	
	public static function GetFieldsForClub($id) {
	
		// Erhalte Field im JSON-Format
		$json = self::ApiCall("clubs/" . $id . "/fields");
	
		$result = array ();
		foreach ($json as $jsonElement) {
	
			array_push($result, new Field($jsonElement));
		}
	
		return $result;
	}

	public static function GetField($id) {
	
		// Erhalte Field im JSON-Format
		$json = self::ApiCall("fields/" . $id);
	
		return new Field($json);
	}
	
	public static function GetTeamsForClub($id){
	
		// Erhalte Team-Array im JSON-Format
		$json = self::ApiCall("clubs/" . $id . "/teams");
	
		$result = array();
		foreach ($json as $jsonElement) {
	
			array_push($result, new Team($jsonElement));
		}
	
		return $result;
	}
	
	public static function GetLicensesForClub($id){
	
		$sortings = array(new SortConfiguration("last_name", "asc"));
		
		// Erhalte License-Array im JSON-Format
		$json = self::ApiCall("clubs/" . $id . "/licenses", $sortings);
	
		$result = array ();
		foreach ($json as $jsonElement) {
	
			array_push($result, new License($jsonElement));
		}
	
		return $result;
	}
	
	public static function GetPerson($id) {
	
		// Erhalte Field im JSON-Format
		$json = self::ApiCall("people/" . $id);
	
		return new Person($json);
	}
	
	public static function GetStatisticsLeague($id, $category) {
	
		switch ($category) {
			case "offense":
				$suffix = "/batting";
				break;
			
			case "defense":
				$suffix = "/fielding";
				break;
			
			case "pitching":
				$suffix = "/pitching";
				break;
			
			default:
				throw new Exception ( "Category has only 3 valid values: 'offense', 'defense' and 'pitching', but '" . $category . "' was set" );
				break;
		}
		// Erhalte League im JSON-Format
		$json = self::ApiCall("leagues/" . $id . "/statistics" . $suffix);
	
		return new StatisticLeagueGroup($json);
	}	
	
	public static function GetStatisticsLeagueTeamForLeague($id, $category) {
	
		switch ($category) {
			case "offense":
				$suffix = "/batting";
				break;
			
			case "defense":
				$suffix = "/fielding";
				break;
			
			case "pitching":
				$suffix = "/pitching";
				break;
			
			default:
				throw new Exception ( "Category has only 3 valid values: 'offense', 'defense' and 'pitching', but '" . $category . "' was set" );
				break;
		}
		
		// Erhalte LeagueEntry-Array im JSON-Format
		$json = self::ApiCall("league_entries/" . $id . "/statistics" . $suffix);
	
		return new StatisticLeagueGroupTeam($json);
	}
	
	public static function GetStatisticsClub($id, $category) {
	
		switch ($category) {
			case "offense":
				$suffix = "/batting";
				break;
					
			case "defense":
				$suffix = "/fielding";
				break;
					
			case "pitching":
				$suffix = "/pitching";
				break;
					
			default:
				throw new Exception ( "Category has only 3 valid values: 'offense', 'defense' and 'pitching', but '" . $category . "' was set" );
				break;
		}
	
		// Erhalte LeagueEntry-Array im JSON-Format
		$json = self::ApiCall("clubs/" . $id . "/statistics" . $suffix);
	
		return new StatisticClub($json);
	}
	
	public static function GetStatisticsLeagueLeaders($id, $category, $option) {
	
		switch ($category) {
			case "offense":
				$suffix = "/batting";
				break;
					
			case "defense":
				$suffix = "/fielding";
				break;
					
			case "pitching":
				$suffix = "/pitching";
				break;
					
			default:
				throw new Exception ( "Category has only 3 valid values: 'offense', 'defense' and 'pitching', but '" . $category . "' was set" );
				break;
		}
		// Erhalte League im JSON-Format
		$json = self::ApiCall("leagues/" . $id . "/top10" . $suffix . "/" . $option);
	
		return new StatisticLeagueGroupLeaders($json);
	}
	
	public static function GetStatisticsPerson($id, $category) {
	
		switch ($category) {
			case "offense":
				$suffix = "/batting";
				break;
					
			case "defense":
				$suffix = "/fielding";
				break;
					
			case "pitching":
				$suffix = "/pitching";
				break;
					
			default:
				throw new Exception ( "Category has only 3 valid values: 'offense', 'defense' and 'pitching', but '" . $category . "' was set" );
				break;
		}
	
		// Erhalte LeagueEntry-Array im JSON-Format
		$json = self::ApiCall("people/" . $id . "/statistics" . $suffix);
	
		return new StatisticPerson($json);
	}
	
	public static function GetBoxscore($id) {

		// Erhalte Boxscore im JSON-Format
		$json = self::ApiCall("matches/" . $id . "/match_boxscore");
		
		return new MatchBoxscore($json);
	}
	
	
}

?>