<?php
include_once ("Localization.php");

class Helper{	
	
	public static function GetBsmPathUrl(){
		
		$basePath = "/bsm/";
		if(function_exists("plugins_url")){
			
			$basePath = plugins_url("bsm-wordpress-plugin" . $basePath);
		}
		else if(function_exists("get_home_url")){
				
			$basePath = get_home_url() . $basePath;
		}
		
		return $basePath;
	}
	
	public static function PlaceholderIfEmpty($string){
		
		return (empty($string) ? Localization::GLOBAL_PLACEHOLDER : $string);
	}	
	
	public static function ReplaceWithEntryIfExists($value, array $dictionary){
		
		if(array_key_exists($value, $dictionary)){
			
			return $dictionary[$value];
		}
		
		return $value;
	}
	
	public static function EncodeUserInputString($userInputString){
		
		return htmlspecialchars(stripslashes($userInputString));
	}
	
	public static function UrlForImage($imageFileName){		
		
		return self::GetBsmPathUrl() . "img/" . $imageFileName;
	}
	
	public static function UrlForDynamicResource($dynamicResourceFileName){
	
		$wpFuncName = "bsm_show_resource";	
		if(function_exists("admin_url") && function_exists($wpFuncName)){
			return admin_url('admin-ajax.php') . "?action=" . $wpFuncName . "&amp;bsm_resource=" . pathinfo($dynamicResourceFileName, PATHINFO_FILENAME);
		}
		return self::GetBsmPathUrl() . "drg/" . $dynamicResourceFileName;
	}
	
	public static function ConvertParameterListToArray($parameterList, $delimiter = ","){
		
		$result = array();

		// Nichts gegeben -> Aussteigen
		if(empty($parameterList)){
			
			return $result;
		}
		
		// Split
		$untrimmedArray = explode($delimiter, $parameterList);
		foreach ($untrimmedArray as $value){
						
			// Entferne Spaces
			$trimmedValue = trim($value);	
			// Nur dann verwenden, wenn der getrimmte Wert nicht leer ist		
			if(!empty($trimmedValue)){			
				array_push($result, $trimmedValue);
			}
		}
		
		return $result;
	}	
	
	public static function hasArrayOnlyValidEntries($arrayToCheck, $arrayValidEntries){
		
		foreach ($arrayToCheck as $entryToCheck){
			if(!in_array($entryToCheck, $arrayValidEntries))
				return false;
		}
		
		return true;
	}	
	
	public static function GetPersonDisplayName($person, $reverseNames = false, $firstNameShort = false){
		
		if(empty($person)){
			return null;			
		}
		
		$personFirstName = $person->GetFirstName();
		if($firstNameShort){
			if(!empty($personFirstName)){
				$personFirstName = substr($personFirstName, 0, 1) . ".";
			}
		}
		
		// Name - MINIMUM Nachname/Vorname muss gegeben sein, um einen vollstndigen Namen anzuzeigen
		$personNameSecondPart = $reverseNames ? $personFirstName: $person->GetLastName();
		if(!empty($personNameSecondPart)){
			
			$personNameFirstPart = $reverseNames ? $person->GetLastName() : $personFirstName;
			if(!empty($personNameFirstPart)){
		
				$personNameSecondPart = $personNameFirstPart . " " . $personNameSecondPart;
			}
			
			$personNamePrefix = $person->GetNamePrefix();			
			if(!empty($personNamePrefix)){
				$personNameSecondPart = $personNamePrefix . " " . $personNameSecondPart;
			}
			
			$personNameSuffix = $person->GetNameSuffix();			
			if(!empty($personNameSuffix)){
				$personNameSecondPart .= " " . $personNameSuffix;
			}
		}
		
		return $personNameSecondPart;
	}	

	//Liefert Adresse als Einzeiler, oder null, wenn eine der ntigen Informationen nicht gegeben ist
	public static function GetFullAddress($contactInfoOrClub){
		
		if(empty($contactInfoOrClub)){
			
			return null;
		}
		
		if(method_exists($contactInfoOrClub, "GetHideInPublic") && $contactInfoOrClub->GetHideInPublic()){
			
			return null;
		}
		
		$street = $contactInfoOrClub->GetStreet();
		$postalCode = $contactInfoOrClub->GetPostalCode();
		$city = $contactInfoOrClub->GetCity();
		
		if(empty($street) || empty($postalCode) || empty($city)){
			
			return null;
		}
		
		return $street . ", " . $postalCode . " " . $city;
	}
	
	public static function GetUsedEMail($contactInfo){
		
		if(empty($contactInfo)){
			
			return null;
		}
		
		$eMail = $contactInfo->GetOrganizationEMail();
		//Falls nicht gegeben, normale EMail
		if(empty($eMail)){
				
			$eMail = $contactInfo->GetEMail();
		}
		
		return $eMail;
	}
	
	public static function GetContactLine($contactInfo){
		
		if(empty($contactInfo)){
				
			return null;
		}
		
		$contactLine = $contactInfo->GetContactName();
		// Evtl. die Erweiterung anfgen
		$contactNameExtension = $contactInfo->GetContactNameExtension();
		if (!empty($contactNameExtension)) {
			// Hauptname war gegeben, fge ein Komma hinzu
			if (!empty($contactLine)){
				$contactLine = $contactLine . ", ";
			}
			// Erweiterung anfgen
			$contactLine = $contactLine . $contactNameExtension;
		}
		
		return $contactLine;
	}
	
	public static function GetContactInfoByMode($mainInfo, $altInfo, $contactMode, $separator){
		
		//Standard = mainInfo
		$result = $mainInfo;		
		//Werden beide angezeigt, oder fallback versucht, mache weiter
		if($contactMode == "both" || $contactMode == "fallback"){
		
			//Ist result leer, nutze nur altInfo
			if(empty($result)){
				
				$result = $altInfo;
			}
			//Ansonsten fge altInfo dann hinzu, wenn beide angezeigt werden sollen und altInfo nicht leer ist
			else if($contactMode == "both" && !empty($altInfo)){
				
				$result = $result . " " . $separator . " " . $altInfo;
			}
		}
		
		return $result;
	}
	
	public static function GetMoney($money){
		if($money === null)
			return null;
		
		return number_format(round($money / (float) 100, 2), 2, Localization::GLOBAL_DECIMAL_POINT, Localization::GLOBAL_THOUSANDS_SEPARATOR) . " " . Localization::GLOBAL_CURRENCY;
	}
	
	public static function EnsureTimeZone(){
		//Standard
		$zone = Api::TIME_ZONE;
		//Aktuelle Einstellung
		$currentZone = date_default_timezone_get();
		//Abweichend
		if($currentZone != $zone){
		
			//Setze Einstellung
			date_default_timezone_set($zone);
		}
	}
		
	public static function GetDateByString($date, $yearOnly = false, $withDayOfWeek = false, $withLongDayOfWeek = false){
		if(empty($date)){
			return null;
		}
		
		self::EnsureTimeZone();
		
		$dateObject = strtotime($date);
		$result = date($yearOnly ? Localization::GLOBAL_DATEFORMAT_YEARONLY : Localization::GLOBAL_DATEFORMAT, $dateObject);
		if($withDayOfWeek || $withLongDayOfWeek){
			
			$daysOfWeek = $withLongDayOfWeek ? Localization::$GLOBAL_DAYSOFWEEK_LONG : Localization::$GLOBAL_DAYSOFWEEK;
			$result = $daysOfWeek[date("w", $dateObject)] . " " . $result;
		}
		
		return $result;
	}	
	
	public static function GetTimeByString($time){
		if(empty($time)){
			return null;
		}
		
		self::EnsureTimeZone();
		
		return date(Localization::GLOBAL_TIMEFORMAT, strtotime($time));
	}
	
	public static function IsPastDateString($date){
		if(empty($date)){
			return false;
		}
		//Nur das Datum interessiert - daher evtl. Zeitangaben entfernen
		$dateObject = strtotime($date);
		return strtotime(date("Y-m-d", $dateObject)) < strtotime(date("Y-m-d"));
	}
	
	public static function daysUntilDateString($date){
		if(empty($date)){
			return null;
		}
		//Nur das Datum interessiert - daher evtl. Zeitangaben entfernen
		$dateObject = strtotime($date);	
		$diff = strtotime(date("Y-m-d", $dateObject)) - strtotime(date("Y-m-d"));
		return ceil($diff /60/60/24);
	}
	
	public static function ToHtmlNumbers($string){
		
		return mb_encode_numericentity($string, array (0x0, 0xffff, 0, 0xffff));
	}
	
	public static function ToMailToLink($email){
		
		return self::ToHtmlNumbers("mailto:" . $email);
	}
	
	public static function ToTelLink($tel){
	
		return self::ToHtmlNumbers("tel:" . $tel);
	}
	
	public static function ToDelimitedList($array){
		
		$result = "";
		if(!empty($array)){
		
			$first = true;
			foreach($array as $value){
				
				if($first){
					$result = $value;
					$first = false;
					continue;
				}
				
				$result = $result . Localization::GLOBAL_DELIMITER . $value;
			}
		}
		
		return $result;
	}
	
	public static function GroupFunctions($functions, $categoryFilter, $functionFilter){
		
		$categoryArray = array();
		
		//Filter nach eingestellter Kategorie / Function und anschlieende Gruppierung
		foreach($functions as $function) {
		
			$groupingCategory = $function->GetCategory();
		
			//Filtern nach Kategorie, wenn diese nicht passt weiter iterieren
			if((!empty($functionFilter) && $functionFilter !== $function->GetName())
					|| (!empty($categoryFilter) && $categoryFilter !== $groupingCategory)){
					
				continue;
			}
		
			//Gruppierung nach Kategorie
			//Wenn inneres Array noch nicht existert, erzeugen
			if(!array_key_exists($groupingCategory, $categoryArray)){
				//Inneres Array erzeugen
				$categoryArray[$groupingCategory] = array();
			}
			//Dem inneren Array den Funktionr hinzufgen
			array_push($categoryArray[$groupingCategory], $function);
		}		
		
		return $categoryArray;
	}
	
	public static function GroupLicenses($licenses, $categoryFilter, $clubFilter, $levelFilter, $groupByClub){
		
		$categoryArray = array();
		
		//Filter nach eingestellter Kategorie / Verein / Stufe und anschlieende Gruppierung nach Kategorie
		foreach($licenses as $license) {
						
			$groupingCategory = $license->GetCategory();
			$groupingClub = $license->GetClubAcronymOrDefault();
		
			//Filtern, wenn nicht passt weiter iterieren
			if((!empty($categoryFilter) && $categoryFilter !== $groupingCategory)
					|| (!empty($clubFilter) && $clubFilter !== $groupingClub)
					|| (!empty($levelFilter) && $levelFilter !== $license->GetLevel())){
					
				continue;
			}
		
			//Gruppierung nach Kategorie
			//Wenn inneres Array noch nicht existert, erzeugen
			if(!array_key_exists($groupingCategory, $categoryArray)){
				//Inneres Array erzeugen
				$categoryArray[$groupingCategory] = array();
			}
			
			if(!$groupByClub){
				$groupingClub = "AllClubsOrOrganizations";
			}
			
			//Gruppierung nach Verein
			//Wenn inneres Array noch nicht existert, erzeugen
			if(!array_key_exists($groupingClub, $categoryArray[$groupingCategory])){
				//Inneres Array erzeugen
				$categoryArray[$groupingCategory][$groupingClub] = array();
			}
			//Dem inneren Array die Lizenz hinzufgen
			array_push($categoryArray[$groupingCategory][$groupingClub], $license);		
		}

		return $categoryArray;
	}
	
	public static function GroupMatches($groupBy, $matches, $leagueFilter, $clubFilter, $clubFilterSettings, $stateExclusionFilter, $leagueExclusionFilter, $leagueInclusionFilter, $dateSetting, $showAdditionalLeague){

		// logging
		if(bsm_get_option("debug") === true) {
		//	error_log("function GroupMatches(groupBy: '$groupBy', matches-count: " . count($matches) . ", league-filter: '$leagueFilter', club-filter: '$clubFilter')");
		}
		
		$matchArray = array();
		$groupBy = empty($groupBy) ? "AllMatches" : $groupBy;
		$stateExclusionFilterArray = empty($stateExclusionFilter) ? null : (is_array($stateExclusionFilter) ? $stateExclusionFilter : self::ConvertParameterListToArray($stateExclusionFilter));
		$leagueExclusionFilterArray = empty($leagueExclusionFilter) ? null : (is_array($leagueExclusionFilter) ? $leagueExclusionFilter : self::ConvertParameterListToArray($leagueExclusionFilter));
		$leagueInclusionFilterArray = empty($leagueInclusionFilter) ? null : (is_array($leagueInclusionFilter) ? $leagueInclusionFilter : self::ConvertParameterListToArray($leagueInclusionFilter));
		
		//Gruppierung nach Datum
		foreach ($matches as $match) {
			
			$match_league = $match->GetLeague();
			$match_extra_rating_league = $match->GetExtraRatingLeague();
			$match_extra_rating_league2 = $match->GetExtraRatingLeague2();
			$match_second_league = $match->GetSecondLeague();
			$foundSecondLeague = false;
			
			//Filtern, wenn nicht passt weiter iterieren
			if(!empty($leagueFilter)){
				
				//Suche
				$foundLeague = false;
				
				//Wenn Liga nicht gegeben oder Liga nicht dem Filter entspricht
				if(!empty($match_league) && ($match_league->GetID() == $leagueFilter || $match_league->GetAcronym() == $leagueFilter)){
					//Gefunden
					$foundLeague = true;
				}
				//RF 2019-03-01: Prfung ob Second-Liga dem Filter entspricht (ist bei Interleague-Spielen so)
				if(!empty($match_second_league) && ($match_second_league->GetID() == $leagueFilter || $match_second_league->GetAcronym() == $leagueFilter)){
					//Gefunden
					$foundLeague = true;
					$foundSecondLeague = true;
				}
				
				//Wenn true, muss nicht weiter geprft werden
				if(!$foundLeague){
					if($showAdditionalLeague){
						if(!empty($match_extra_rating_league) && ($match_extra_rating_league->GetID() == $leagueFilter || $match_extra_rating_league->GetAcronym() == $leagueFilter)){
							//Gefunden
							$foundLeague = true;
						}
						if(!empty($match_extra_rating_league2) && ($match_extra_rating_league2->GetID() == $leagueFilter || $match_extra_rating_league2->GetAcronym() == $leagueFilter)){
							//Gefunden
							$foundLeague = true;
						}
					}
				}
				
				//Wenn noch immer false, DS nicht nutzen
				if(!$foundLeague){
					continue;
				}
			}
				
			//Nur Spiele, nach Einstellung
			if(!empty($clubFilter)){
				
				//Einstellungen
				$clubFilterSettingsArray = self::ConvertParameterListToArray($clubFilterSettings);
				$ignoreFilterSettings = empty($clubFilterSettingsArray);				
				
				//Suche
				$foundClub = false;
			
				//Home
				if($ignoreFilterSettings || in_array("home", $clubFilterSettingsArray)){
					$homeEntry = $match->GetHomeLeagueEntry();
					if(!empty($homeEntry)){
						$homeTeam = $homeEntry->GetTeam();
						if(!empty($homeTeam)){
							$homeClubs = $homeTeam->GetClubs();
							if(!empty($homeClubs)){
								foreach ($homeClubs as $homeClub){
									if($homeClub->GetID() == $clubFilter || $homeClub->GetAcronym() == $clubFilter){
										//Gefunden
										$foundClub = true;
										//Rest nicht durchsuchen
										break;
									}
								}
							}
						}
					}
				}
			
				//Wenn true, muss nicht weiter geprft werden
				if(!$foundClub && ($ignoreFilterSettings || in_array("away", $clubFilterSettingsArray))){
					//Away
					$awayEntry = $match->GetAwayLeagueEntry();
					if(!empty($awayEntry)){
						$awayTeam =  $awayEntry->GetTeam();
						if(!empty($awayTeam)){
							$awayClubs = $awayTeam->GetClubs();
							if(!empty($awayClubs)){
								foreach ($awayClubs as $awayClub){
									if($awayClub->GetID() == $clubFilter || $awayClub->GetAcronym() == $clubFilter){
										//Gefunden
										$foundClub = true;
										//Rest nicht durchsuchen
										break;
									}
								}
							}
						}
					}
				}
				
				//Wenn true, muss nicht weiter geprft werden
				if(!$foundClub && ($ignoreFilterSettings || in_array("umpireselection", $clubFilterSettingsArray))){				
					$umpire = $match->GetUmpireSelection();
					if(!empty($umpire)){
						$umpireAcronym = $umpire->GetAcronym();
						if($umpire->GetID() == $clubFilter || $umpireAcronym == $clubFilter){
							//Gefunden
							$foundClub = true;
						}
					}
				}
				
				//Wenn true, muss nicht weiter geprft werden
				if(!$foundClub && ($ignoreFilterSettings || in_array("scorerselection", $clubFilterSettingsArray))){				
					//Scorer - nur wenn noch nicht sowieso enthalten
					$scorer = $match->GetScorerSelection();
					if(!empty($scorer)){
						$scorerAcronym = $scorer->GetAcronym();
						if($scorer->GetID() == $clubFilter || $scorerAcronym == $clubFilter){
							//Gefunden
							$foundClub = true;
						}
					}
				}
			
				//Wenn noch immer false, DS nicht nutzen
				if(!$foundClub){
					continue;
				}
			}
			
			//Filtern, wenn nicht passt weiter iterieren
			if(!empty($stateExclusionFilterArray)){
				
				//Wenn Status in Exklusion
				if(in_array($match->GetState(), $stateExclusionFilterArray)){
					continue;
				}
			}
			
			//Filtern, wenn nicht passt weiter iterieren
			if(!empty($leagueExclusionFilterArray)){
			
				//Wenn Liga gegeben und in Exklusion, DS nicht nutzen
				// RF 2019-03-04: Ausnahme: Der DS ist ein Interleague Spiel das gezeigt werden soll (secondLeague)
				if(!empty($match_league) 
						&& (in_array($match_league->GetID(), $leagueExclusionFilterArray) 
							|| in_array($match_league->GetAcronym(), $leagueExclusionFilterArray))
						&& !$foundSecondLeague){
					continue;
				}
				// RF: auskommentiert weil sonst Spiele rausfallen wrden, die lediglich AUCH in einer anderen Liga gezeigt werden
				/*
				//Wenn Liga gegeben und in Exklusion
				if(!empty($match_extra_rating_league) && (in_array($match_extra_rating_league->GetID(), $leagueExclusionFilterArray) || in_array($match_extra_rating_league->GetAcronym(), $leagueExclusionFilterArray))){
					continue;
				}
				*/
			}		

			//Filtern, wenn nicht passt weiter iterieren
			if(!empty($leagueInclusionFilterArray)){					

				//Suche
				$foundLeague = false;
				
				//Wenn Liga gegeben und in Inklusion
				if(!empty($match_league) 
						&& (in_array($match_league->GetID(), $leagueInclusionFilterArray) 
							|| in_array($match_league->GetAcronym(), $leagueInclusionFilterArray))){
					//Gefunden
					$foundLeague = true;
				}
				
				//Wenn true, muss nicht weiter geprft werden
				if(!$foundLeague){
					if($showAdditionalLeague){
						if(!empty($match_extra_rating_league) && (in_array($match_extra_rating_league->GetID(), $leagueInclusionFilterArray) || in_array($match_extra_rating_league->GetAcronym(), $leagueInclusionFilterArray))){
							//Gefunden
							$foundLeague = true;
						}
						if(!empty($match_extra_rating_league2) && (in_array($match_extra_rating_league2->GetID(), $leagueInclusionFilterArray) || in_array($match_extra_rating_league2->GetAcronym(), $leagueInclusionFilterArray))){
							//Gefunden
							$foundLeague = true;
						}
					}
				}
				
				//Wenn noch immer false, DS nicht nutzen
				if(!$foundLeague){
					continue;
				}
			}
			
			$grouping = $groupBy == "date" 
					? self::GetDateByString($match->GetTime(), false, $dateSetting === "short", $dateSetting === "long") 
					: ($groupBy == "league"
							? $match->GetLeague()->GetName()
							: $groupBy);
			
			//Wenn inneres Array noch nicht existert, erzeugen
			if(!array_key_exists($grouping, $matchArray)){
				//Inneres Array erzeugen
				$matchArray[$grouping] = array();
			}
			//Dem inneren Array das Spiel hinzufgen
			array_push($matchArray[$grouping], $match);
		}
		
		// logging
		if(bsm_get_option("debug") === true) {
		//	error_log("function GroupMatches() returns matches-count: " . count($matchArray[$grouping]) . "");
		}
		
		return $matchArray;
	}

	/* TODO */
	public static function GroupGroupMatches($groupBy1, $groupBy2, $matches, $leagueFilter, $clubFilter, $clubFilterSettings, $stateExclusionFilter, $leagueExclusionFilter, $leagueInclusionFilter, $dateSetting, $showAdditionalLeague){
	
		$groupArray = array();
		$stateExclusionFilterArray = empty($stateExclusionFilter) ? null : (is_array($stateExclusionFilter) ? $stateExclusionFilter : self::ConvertParameterListToArray($stateExclusionFilter));
		$leagueExclusionFilterArray = empty($leagueExclusionFilter) ? null : (is_array($leagueExclusionFilter) ? $leagueExclusionFilter : self::ConvertParameterListToArray($leagueExclusionFilter));
		$leagueInclusionFilterArray = empty($leagueInclusionFilter) ? null : (is_array($leagueInclusionFilter) ? $leagueInclusionFilter : self::ConvertParameterListToArray($leagueInclusionFilter));
		
		//Gruppierung nach Datum oder Liga (1. Ebene)
		foreach ($matches as $match) {
			$match_league = $match->GetLeague();
			
			//Filtern, wenn nicht passt weiter iterieren
			if(!empty($stateExclusionFilterArray)){
				
				//Wenn Status in Exklusion
				if(in_array($match->GetState(), $stateExclusionFilterArray)){
					continue;
				}
			}
			
			//Filtern, wenn nicht passt weiter iterieren
			if(!empty($leagueExclusionFilterArray)){
			
				//Wenn Liga gegeben und in Exklusion, DS nicht nutzen
				// RF 2019-03-04: Ausnahme: Der DS ist ein Interleague Spiel das gezeigt werden soll (secondLeague)
				if(!empty($match_league) 
						&& (in_array($match_league->GetID(), $leagueExclusionFilterArray) 
							|| in_array($match_league->GetAcronym(), $leagueExclusionFilterArray))
						&& !$foundSecondLeague){
					continue;
				}
				// RF: auskommentiert weil sonst Spiele rausfallen wrden, die lediglich AUCH in einer anderen Liga gezeigt werden
				/*
				//Wenn Liga gegeben und in Exklusion
				if(!empty($match_extra_rating_league) && (in_array($match_extra_rating_league->GetID(), $leagueExclusionFilterArray) || in_array($match_extra_rating_league->GetAcronym(), $leagueExclusionFilterArray))){
					continue;
				}
				*/
			}		

			//Filtern, wenn nicht passt weiter iterieren
			if(!empty($leagueInclusionFilterArray)){					

				//Suche
				$foundLeague = false;
				
				//Wenn Liga gegeben und in Inklusion
				if(!empty($match_league) 
						&& (in_array($match_league->GetID(), $leagueInclusionFilterArray) 
							|| in_array($match_league->GetAcronym(), $leagueInclusionFilterArray))){
					//Gefunden
					$foundLeague = true;
				}
				
				//Wenn true, muss nicht weiter geprft werden
				if(!$foundLeague){
					if($showAdditionalLeague){
						if(!empty($match_extra_rating_league) && (in_array($match_extra_rating_league->GetID(), $leagueInclusionFilterArray) || in_array($match_extra_rating_league->GetAcronym(), $leagueInclusionFilterArray))){
							//Gefunden
							$foundLeague = true;
						}
						if(!empty($match_extra_rating_league2) && (in_array($match_extra_rating_league2->GetID(), $leagueInclusionFilterArray) || in_array($match_extra_rating_league2->GetAcronym(), $leagueInclusionFilterArray))){
							//Gefunden
							$foundLeague = true;
						}
					}
				}
				
				//Wenn noch immer false, DS nicht nutzen
				if(!$foundLeague){
					continue;
				}
			}
			
			$grouping = $groupBy1 == "date" 
					? self::GetDateByString($match->GetTime(), false, $dateSetting === "short", $dateSetting === "long") 
					: ($groupBy1 == "league"
							? $match->GetLeague()->GetName()
							: $groupBy1);
			
			//Wenn inneres Array noch nicht existert, erzeugen
			if(!array_key_exists($grouping, $groupArray)){
				//Inneres Array erzeugen
				$groupArray[$grouping] = array();
			}
			//Dem inneren Array das Spiel hinzufgen
			array_push($groupArray[$grouping], $match);
		}
		
		//Gruppierung nach Datum oder Liga (2. Ebene)
		foreach ($groupArray as $grouping => $groupMatches) {
			//Dem Array das Array der 2. Ebene hinzufgen (vorher leeren weil aktuell ja die Spiele drin sind)
			$returnMatches = self::GroupMatches($groupBy2, $groupMatches, $leagueFilter, $clubFilter, $clubFilterSettings, $stateExclusionFilter, $leagueExclusionFilter, $leagueInclusionFilter, $dateSetting, $showAdditionalLeague);
			$groupArray[$grouping] = $returnMatches;
			//array_push($groupArray[$grouping], $returnMatches);
		}
		
		return $groupArray;
	}

}
?>