<?php

function bsm_get_options(){
	return get_option("bsm_options");
}

function bsm_get_option($option){
	$options = bsm_get_options();
	return (!empty($options)) ? $options[$option] : null;
}

// Options Menu
function bsm_manage_options(){

	if (!current_user_can("manage_options")) {
		// WP Localization Key
		wp_die(__("You do not have sufficient permissions to access this page."));
	}

	// Build Markup
	echo "<div class=\"wrap\">";
	echo "	<h2>" . __( "BSM", "menu" ) . "</h2>";
	echo "		<form method=\"post\" action=\"options.php\">";

	echo settings_fields("bsm_options");
	echo do_settings_sections("bsm");

	echo "			<p class=\"submit\">";
	echo "				<input type=\"submit\" name=\"Submit\" class=\"button-primary\" value=\"" . "Save" . "\" />";
	echo "			</p>";
	echo "		</form>";
	echo "</div>";
}

function bsm_manage_options_menu(){

	// Register Page
	add_options_page("BSM", "BSM", "manage_options", "bsm", "bsm_manage_options");
}

add_action("admin_menu", "bsm_manage_options_menu");

//Settings Menu Page
function bsm_option_apiKey(){

	$option = bsm_get_option("apiKey");

	echo "<input id=\"bsm_apiKey\" name=\"bsm_options[apiKey]\" type=\"text\" value=\"" . $option . "\" />";
}
function bsm_option_orgId(){

	$option = bsm_get_option("orgId");

	echo "<input id=\"bsm_orgId\" name=\"bsm_options[orgId]\" type=\"number\" value=\"" . $option . "\" />";
}
function bsm_option_season(){

	$option = bsm_get_option("season");

	echo "<input id=\"bsm_season\" name=\"bsm_options[season]\" type=\"number\" value=\"" . $option . "\" />";
}
function bsm_option_debug(){

	$option = bsm_get_option("debug");

	echo "<input id=\"bsm_debug\" name=\"bsm_options[debug]\" type=\"checkbox\"" . (!empty($option) ? " checked=\"checked\"" : "") . " />";
}

function bsm_options_validate($input){

	$options = bsm_get_options();

	$options["apiKey"] = wp_filter_nohtml_kses($input["apiKey"]);
	$options["orgId"] = intval($input["orgId"]);
	$options["season"] = intval($input["season"]);
	$options["debug"] = !empty($input["debug"]);

	return $options;
}

function bsm_section_text (){ }

function bsm_admin_init(){

	register_setting("bsm_options", "bsm_options", "bsm_options_validate");

	add_settings_section("bsm_main", "Main Settings", "bsm_section_text", "bsm");

	add_settings_field("bsm_apiKey", "<label for=\"bsm_apiKey\">Api Key</label>", "bsm_option_apiKey", "bsm", "bsm_main");
	add_settings_field("bsm_orgId", "<label for=\"bsm_orgId\">Organization ID</label>", "bsm_option_orgId", "bsm", "bsm_main");
	add_settings_field("bsm_season", "<label for=\"bsm_season\">Season</label>", "bsm_option_season", "bsm", "bsm_main");
	add_settings_field("bsm_debug", "<label for=\"bsm_debug\">Debug Mode</label>", "bsm_option_debug", "bsm", "bsm_main");
}

add_action("admin_init", "bsm_admin_init");

// Load Settings into BSM
include_once ("bsm/data/Api.php");

$options = bsm_get_options();
if(!empty($options)){
	// Try to set the new values if the options 'bsm_options' are given
	$apiKey = $options["apiKey"];
	$orgId = $options["orgId"];
	$season = $options["season"];

	//Try to init
	try{
		Api::InitConfig($apiKey, $orgId, $season);
	}
	catch(Exception $e){
		//Do nothing
	}

	// suppress warnings in production mode
	$debug = $options["debug"];
	if($debug === true) {
		//echo("debug mode: ON");
		error_log("*** DEBUG MODE ***");
		error_reporting(E_ALL);
	} else {
		error_reporting(E_ALL & ~E_NOTICE & ~E_WARNING);
	}
}

?>